#
# spec file for package vdr-plugin-mcli
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

# svn co https://svn.baycom.de/repos/vdr-mcli-plugin/
# tar cj --exclude=.svn -f vdr-mcli-plugin.tar.bz2 vdr-mcli-plugin

%define pluginversion 0.9.186
%define pluginname mcli
%define pluginurl http://www.baycom.de
#
%define plugindir vdr-mcli-plugin
%define plugintarball vdr-%{pluginname}-plugin.tar.bz2
#
%define pkgversion %pluginversion

Name:           vdr-plugin-mcli
Version:        %{pkgversion}
Release:        pm151.5.11
Summary:        VDR %{pluginname} plugin
License:        GPL-2.0 and LGPL-2.1
Group:          Hardware/TV
Url:            %{pluginurl}
Source:         %{plugintarball}
Source1:        sysconfig.vdr-mcli
Patch0:         vdr-mcli-Makefile.diff
Patch1:         vdr-mcli_device.patch
Patch2:         vdr-mcli.abs.patch
Patch3:         vdr-mcli.buffersize.patch
BuildRequires:  gcc-c++
BuildRequires:  libxml2-devel
BuildRequires:  pkg-config
BuildRequires:  vdr-devel
#
PreReq:         %fillup_prereq
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         vdr(abi) = %{vdr_apiversion}
# used to be in vdr-plugins
Provides:       vdr-plugins:%{_docdir}/vdr/plugins/%{pluginname}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
%{vdrname} %{pluginname} plugin
With this plugin you can use a reel/baycom netciver in vdr.

%package -n libmcli
Summary:        Shared library %{name}
Group:          System/Libraries

%description -n libmcli
Package contains the libmcli shared library

%package -n netceiver-tools
Summary:        Commandline tools for netciver management
Group:          Productivity/Multimedia/Other
Requires:       libmcli = %{version}-%{release}

%description -n netceiver-tools
A view commandline programs to work with the netceiver
* mcli         - creats dvb devices with dvbloop kernel module
* netcvdiag    - diagnostic
* netcvlogview - view logfiles
* netcvupdate  - update firmware
* netcv2dvbip  - lets netciver be used by vlc

%prep
%setup -q -n %{plugindir}
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Fix file-contains-date-and-time
DateTime=$(date --date "`stat --format %y %{_sourcedir}/%{name}.changes`" +"%b %d %H:%M %Y")
sed -i 's/__DATE__"\ "__TIME__/\"'"$DateTime"'\"/g' mcast/common/version.h

%build
export SUSE_ASNEEDED=0
# Old macro -> Use "make" for modern plugins
%vdr_make libmcli.so
%vdr_make
cd mcast/tool
make %{?_smp_mflags}
cd ../client
make mcli %{?_smp_mflags}
cd ../netcv2dvbip
make %{?_smp_mflags}

%install
# Use "make install" for modern plugins
install -d -m 755 %{buildroot}%{_libdir}
install -m 755 mcast/client/libmcli.so %{buildroot}%{_libdir}
install -d -m 755 %{buildroot}%{_bindir}
install -m 755 mcast/tool/netcvdiag %{buildroot}%{_bindir}
install -m 755 mcast/tool/netcvlogview %{buildroot}%{_bindir}
install -m 755 mcast/tool/netcvupdate %{buildroot}%{_bindir}
install -m 755 mcast/client/mcli %{buildroot}%{_bindir}
install -m 755 mcast/netcv2dvbip/netcv2dvbip %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{vdr_sysconfdir}/plugins/mcli
# sysconfig
install -d -m 755 %{buildroot}%{_fillupdir}
install -m 644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.%{vdrname}-mcli
# Removed the older macro vdr_install_plugin
for i in %{pluginname}; do
install -D -m 755 libvdr-$i.so %{buildroot}%{vdr_libdir}/libvdr-$i.so.%{vdr_apiversion}
done 
# Use vdr_find_locale_name macro on openSUSE > 13.1
if [ -d locale ]; then 
  cd locale 
  install -d -m 755 %buildroot%{vdr_localedir} 
  for i in *_*; do 
	  install -d -m 755 %buildroot%{vdr_localedir}/$i/LC_MESSAGES 
	  install -m 644 $i/LC_MESSAGES/*.mo %buildroot%{vdr_localedir}/$i/LC_MESSAGES 
  done 
  cd .. 
fi

%find_lang vdr-%{pluginname}

%post -n libmcli -p /sbin/ldconfig

%postun -n libmcli -p /sbin/ldconfig

%post
%{fillup_only -n %{vdrname} -s mcli}

%files -f vdr-%{pluginname}.lang
%defattr(-,root,root)
%doc COPYING HISTORY README
%{vdr_libdir}/*
%attr(-,vdr,root) %dir %{vdr_sysconfdir}/plugins
%attr(-,vdr,root) %dir %{vdr_sysconfdir}/plugins/mcli
%{_fillupdir}/sysconfig.%{vdrname}-mcli

%files -n libmcli
%defattr(-,root,root)
%{_libdir}/libmcli.so

%files -n netceiver-tools
%defattr(-,root,root)
%{_bindir}/*

%changelog
* Wed Oct 22 2014 avvissu@yandex.ru
- Fix build errors (add vdr-mcli_device.patch)
- Fix file-contains-date-and-time
- Removed the older macros vdr_install_plugin{_locale}
- Spec file cleanup
* Fri Aug 19 2011 Manfred.Tremmel@iiv.de
- update to svn 186
* Sun Jan 16 2011 Manfred.Tremmel@iiv.de 
- update to svn 176
* Sun Jun 20 2010 Manfred.Tremmel@iiv.de 
- included lib and utils
* Sat Jun 19 2010 Manfred.Tremmel@iiv.de 
- update to svn 106
* Sat Jun 12 2010 Manfred.Tremmel@iiv.de 
- first packman build, svn checkout 2010-06-09
